@@ -53,7 +53,7 @@ cat(paste("     maximum log-likelihood:", round(x$loglik,2))," \n")
 cat(paste("     AIC:", round(-2*x$loglik+2*length(x$best),2))," \n")
 cat(paste("     BIC:", round(-2*x$loglik+length(x$best)*log(x$ns),2))," \n")
 cat(" \n")
-if (x$Ydiscrete==1){
+if (x$Ydiscrete==1&x$N[6]==0){
 cat(paste("     Discrete posterior log-likelihood:", round(x$discrete_loglik,2))," \n")
 cat(paste("     Discrete AIC:", round(-2*x$discrete_loglik+2*length(x$best),2))," \n")
 cat(" \n")
